@@ -67,7 +67,11 @@ sub query_string_authentication_uri {
         = $self->_encode( $aws_secret_access_key, $canonical_string );
 
     my $protocol = $self->s3->secure ? 'https' : 'http';
-    my $uri = URI->new("$protocol://s3.amazonaws.com/$path");
+    my $uri = "$protocol://s3.amazonaws.com/$path";
+    if ( $path =~ m{^([^/?]+)(.*)} && _is_dns_bucket($1) ) {
+        $uri = "$protocol://$1.s3.amazonaws.com$2";
+    }
+    $uri = URI->new($uri);
 
     $uri->query_param( AWSAccessKeyId => $aws_access_key_id );
     $uri->query_param( Expires        => $expires );
